# Construct Quantum Neural Network using [Tensorflow-quantum](https://www.tensorflow.org/quantum/overview) or [Qiskit](https://qiskit.org/textbook/ch-machine-learning/machine-learning-qiskit-pytorch.html#quantumlayer)

## 1. How to run
- Checkout
```
pip install quhep
```
